@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use File::Flock;
 use List::Util qw(max first);
@@ -1006,12 +1006,8 @@ sub get_max_gid {
 }
 
 sub _enc_pass {
-    require UUID::Random;
-    require Digest::MD5;
-
-    my $pass = shift;
-    my $salt = substr(Digest::MD5::md5_base64(UUID::Random::generate()), 0, 8);
-    crypt($pass, '$6$'.$salt.'$');
+    require Crypt::Password::Util;
+    Crypt::Password::Util::crypt(shift);
 }
 
 sub _add_group_or_user {
@@ -1826,7 +1822,7 @@ Unix::Passwd::File - Manipulate /etc/{passwd,shadow,group,gshadow} entries
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
